          {% extends 'email/base.html' %}
            {% block content %}
              <p>Hello! Someone sent you a message through the contact form.</p>

							<p>
								Name: {{name}}<br>
								Email: {{email}}<br>
								Phone: {{phone}}<br>
							</p>

							<p>{{message}}</p>
            {% endblock content %}