# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-17 20:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0006_merge_20170112_2144'),
    ]

    operations = [
        migrations.CreateModel(
            name='Lead',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name')),
                ('email', models.CharField(max_length=100, verbose_name='Email')),
                ('phone', models.CharField(blank=True, max_length=30, null=True, verbose_name='Phone')),
                ('country', models.CharField(blank=True, max_length=2, null=True, verbose_name='Country')),
            ],
            options={
                'verbose_name_plural': 'Leads',
                'verbose_name': 'Lead',
            },
        ),
    ]
