# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 14:17
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_core', '0004_load_skills_and_causes'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cause',
            options={'verbose_name': 'cause'},
        ),
    ]
